@@ -11,11 +11,11 @@ __all__ = [
     '__license__']
 
 __title__ = 'configlogging'
-__summary__ = "Helper for configuring stdlib's logging module"
+__summary__ = 'Simple helper moudle for configuring Python logging'
 
 __url__ = 'https://github.com/dgilland/configlogging'
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 __author__ = 'Derrick Gilland'
 __email__ = 'dgilland@gmail.com'
